==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d7/d4b/settings__gui_8cpp.js <==
var settings__gui_8cpp =
[
    [ "BaseSetTextfileWindow", "da/d66/structBaseSetTextfileWindow.html", "da/d66/structBaseSetTextfileWindow" ],
    [ "GameOptionsWindow", "d2/d22/structGameOptionsWindow.html", "d2/d22/structGameOptionsWindow" ],
    [ "SettingFilter", "d5/df8/structSettingFilter.html", "d5/df8/structSettingFilter" ],
    [ "BaseSettingEntry", "df/d1c/structBaseSettingEntry.html", "df/d1c/structBaseSettingEntry" ],
    [ "SettingEntry", "d3/d28/structSettingEntry.html", "d3/d28/structSettingEntry" ],
    [ "SettingsContainer", "d2/dc0/structSettingsContainer.html", "d2/dc0/structSettingsContainer" ],
    [ "SettingsPage", "df/d7f/structSettingsPage.html", "df/d7f/structSettingsPage" ],
    [ "GameSettingsWindow", "d6/d69/structGameSettingsWindow.html", "d6/d69/structGameSettingsWindow" ],
    [ "CustomCurrencyWindow", "d7/d95/structCustomCurrencyWindow.html", "d7/d95/structCustomCurrencyWindow" ],
    [ "RestrictionMode", "d7/d4b/settings__gui_8cpp.html#a8931e5e0adf204a4fc99ce3241cbed6b", [
      [ "RM_BASIC", "d7/d4b/settings__gui_8cpp.html#a8931e5e0adf204a4fc99ce3241cbed6baf3497a9394c129ca97970c6c32fa248d", null ],
      [ "RM_ADVANCED", "d7/d4b/settings__gui_8cpp.html#a8931e5e0adf204a4fc99ce3241cbed6ba52174184cf822f52d1462038582c3537", null ],
      [ "RM_ALL", "d7/d4b/settings__gui_8cpp.html#a8931e5e0adf204a4fc99ce3241cbed6ba6a8b86850f0749c1e08f2babfc06bec7", null ],
      [ "RM_CHANGED_AGAINST_DEFAULT", "d7/d4b/settings__gui_8cpp.html#a8931e5e0adf204a4fc99ce3241cbed6ba4f13c6cff03d67655455b3a851674dc0", null ],
      [ "RM_CHANGED_AGAINST_NEW", "d7/d4b/settings__gui_8cpp.html#a8931e5e0adf204a4fc99ce3241cbed6ba91113411f2040ccd2be26693d5a2f011", null ],
      [ "RM_END", "d7/d4b/settings__gui_8cpp.html#a8931e5e0adf204a4fc99ce3241cbed6bac88a0e985553617b75e8e3ac626a911a", null ]
    ] ],
    [ "SettingEntryFlags", "d7/d4b/settings__gui_8cpp.html#a7cea93fb55ed4e66386d11511a1cf2c7", [
      [ "SEF_LEFT_DEPRESSED", "d7/d4b/settings__gui_8cpp.html#a7cea93fb55ed4e66386d11511a1cf2c7a26203bcd0b94df3f87282d8303aba233", null ],
      [ "SEF_RIGHT_DEPRESSED", "d7/d4b/settings__gui_8cpp.html#a7cea93fb55ed4e66386d11511a1cf2c7a4d3449d382a6b0f308c6b89d21eca6e2", null ],
      [ "SEF_BUTTONS_MASK", "d7/d4b/settings__gui_8cpp.html#a7cea93fb55ed4e66386d11511a1cf2c7a09650e1d5e5c246a8637d9a7f74ab965", null ],
      [ "SEF_LAST_FIELD", "d7/d4b/settings__gui_8cpp.html#a7cea93fb55ed4e66386d11511a1cf2c7a3ee0d81884f1d9a8547a9e4a1fd56056", null ],
      [ "SEF_FILTERED", "d7/d4b/settings__gui_8cpp.html#a7cea93fb55ed4e66386d11511a1cf2c7a08b2c987991eb72e04e0e91b863fc964", null ]
    ] ],
    [ "WarnHiddenResult", "d7/d4b/settings__gui_8cpp.html#a2bbffaf9a311c332f2ab5ed047d5ec7a", [
      [ "WHR_NONE", "d7/d4b/settings__gui_8cpp.html#a2bbffaf9a311c332f2ab5ed047d5ec7aacd4f45a3c2d7674cfa0b8a46fafc24b1", null ],
      [ "WHR_CATEGORY", "d7/d4b/settings__gui_8cpp.html#a2bbffaf9a311c332f2ab5ed047d5ec7aab4c93e23115cf6a4476ec54773017477", null ],
      [ "WHR_TYPE", "d7/d4b/settings__gui_8cpp.html#a2bbffaf9a311c332f2ab5ed047d5ec7aae92fef92582c86923381ec86599bce82", null ],
      [ "WHR_CATEGORY_TYPE", "d7/d4b/settings__gui_8cpp.html#a2bbffaf9a311c332f2ab5ed047d5ec7aa0c12831bf021711b95b21e9f5acfc1f4", null ]
    ] ],
    [ "assert_compile", "d7/d4b/settings__gui_8cpp.html#a172675adca0e578e79f65284adfa8d6a", null ],
    [ "BuildMusicSetDropDownList", "d7/d4b/settings__gui_8cpp.html#a2ffbeab3e1519bd0b654596fd654a959", null ],
    [ "BuildSetDropDownList", "d7/d4b/settings__gui_8cpp.html#ab48d85357c4b88ba71e240d29b214ec6", null ],
    [ "DrawArrowButtons", "d7/d4b/settings__gui_8cpp.html#a5d2ef420677f50bfe351d073a57ca7ff", null ],
    [ "DrawBoolButton", "d7/d4b/settings__gui_8cpp.html#abcabc98fb9356f812b54d374c78fb460", null ],
    [ "DrawDropDownButton", "d7/d4b/settings__gui_8cpp.html#a9638c8f5a5d74ccb7cbe669e7aaf1629", null ],
    [ "GetCurRes", "d7/d4b/settings__gui_8cpp.html#a7ece31a3f329c762f64c0200663901e5", null ],
    [ "GetSettingsTree", "d7/d4b/settings__gui_8cpp.html#a9a94fdf20959d3e921977e7bc156dae1", null ],
    [ "InitGRFTownGeneratorNames", "d7/d4b/settings__gui_8cpp.html#aece86b3ea3e76cfc8927ff15cbec6065", null ],
    [ "ResolveVariableAddress", "d7/d4b/settings__gui_8cpp.html#a90ae8fb6d43619feb551ed14263750b3", null ],
    [ "ShowBaseSetTextfileWindow", "d7/d4b/settings__gui_8cpp.html#aad1a23f107dec8e03727d609fcdfe93a", null ],
    [ "ShowCustCurrency", "d7/d4b/settings__gui_8cpp.html#aca9f5c3d690c67d95f4f287dcf4ca155", null ],
    [ "ShowGameOptions", "d7/d4b/settings__gui_8cpp.html#af487449e7f642d3ab0a977a042027bda", null ],
    [ "ShowGameSettings", "d7/d4b/settings__gui_8cpp.html#ab8c4fab0620f49f44008aacd2cd6b81b", null ],
    [ "TownName", "d7/d4b/settings__gui_8cpp.html#ac898761b16af3ae7c3d874b8c39a4c5e", null ],
    [ "_autosave_dropdown", "d7/d4b/settings__gui_8cpp.html#ae6c8bccc9918afa3520760088a135cff", null ],
    [ "_circle_size", "d7/d4b/settings__gui_8cpp.html#af713f7a0af602dafcf93ec92a20936bc", null ],
    [ "_cust_currency_desc", "d7/d4b/settings__gui_8cpp.html#a352bcc7f3d9dc9de508071975a8eb385", null ],
    [ "_driveside_dropdown", "d7/d4b/settings__gui_8cpp.html#a3d4845a92b61fd2769b07caf227e8d01", null ],
    [ "_game_options_desc", "d7/d4b/settings__gui_8cpp.html#a91d0cedcb5e29ca3a43ef97e8c4f83e1", null ],
    [ "_game_settings_restrict_dropdown", "d7/d4b/settings__gui_8cpp.html#ae4952de0118e16ae467a5874a6c39139", null ],
    [ "_grf_names", "d7/d4b/settings__gui_8cpp.html#a8317f958d147368990c0d203cac2f552", null ],
    [ "_gui_zoom_dropdown", "d7/d4b/settings__gui_8cpp.html#a008b3f6522d40f808efaaac5eee46702", null ],
    [ "_nb_grf_names", "d7/d4b/settings__gui_8cpp.html#a7fc3de8da90e3d21442a525d17180c47", null ],
    [ "_nb_orig_names", "d7/d4b/settings__gui_8cpp.html#ab27cd2489945547b7ceca1380cf284c6", null ],
    [ "_nested_cust_currency_widgets", "d7/d4b/settings__gui_8cpp.html#a61ac2226b107c78cff5ba8298cfd2cbb", null ],
    [ "_nested_game_options_widgets", "d7/d4b/settings__gui_8cpp.html#a1e5e26b10a8663b7e0143cee014a0bbe", null ],
    [ "_nested_settings_selection_widgets", "d7/d4b/settings__gui_8cpp.html#a0a52e6243aeee2b7e8749040cba63eda", null ],
    [ "_settings_selection_desc", "d7/d4b/settings__gui_8cpp.html#a8daa5484153bee0c2613a012cefbcc2d", null ],
    [ "LEVEL_WIDTH", "d7/d4b/settings__gui_8cpp.html#a8e9a8ce2c965afd5bc1d8014c9501060", null ],
    [ "SETTING_HEIGHT", "d7/d4b/settings__gui_8cpp.html#aaed4994b463560191c5c7daa9ebb6387", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d7/d4b/settings__gui_8cpp.js <==
var settings__gui_8cpp =
[
    [ "BaseSetTextfileWindow", "da/d66/structBaseSetTextfileWindow.html", "da/d66/structBaseSetTextfileWindow" ],
    [ "GameOptionsWindow", "d2/d22/structGameOptionsWindow.html", "d2/d22/structGameOptionsWindow" ],
    [ "SettingFilter", "d5/df8/structSettingFilter.html", "d5/df8/structSettingFilter" ],
    [ "BaseSettingEntry", "df/d1c/structBaseSettingEntry.html", "df/d1c/structBaseSettingEntry" ],
    [ "SettingEntry", "d3/d28/structSettingEntry.html", "d3/d28/structSettingEntry" ],
    [ "SettingsContainer", "d2/dc0/structSettingsContainer.html", "d2/dc0/structSettingsContainer" ],
    [ "SettingsPage", "df/d7f/structSettingsPage.html", "df/d7f/structSettingsPage" ],
    [ "GameSettingsWindow", "d6/d69/structGameSettingsWindow.html", "d6/d69/structGameSettingsWindow" ],
    [ "CustomCurrencyWindow", "d7/d95/structCustomCurrencyWindow.html", "d7/d95/structCustomCurrencyWindow" ],
    [ "RestrictionMode", "d7/d4b/settings__gui_8cpp.html#a8931e5e0adf204a4fc99ce3241cbed6b", [
      [ "RM_BASIC", "d7/d4b/settings__gui_8cpp.html#a8931e5e0adf204a4fc99ce3241cbed6baf3497a9394c129ca97970c6c32fa248d", null ],
      [ "RM_ADVANCED", "d7/d4b/settings__gui_8cpp.html#a8931e5e0adf204a4fc99ce3241cbed6ba52174184cf822f52d1462038582c3537", null ],
      [ "RM_ALL", "d7/d4b/settings__gui_8cpp.html#a8931e5e0adf204a4fc99ce3241cbed6ba6a8b86850f0749c1e08f2babfc06bec7", null ],
      [ "RM_CHANGED_AGAINST_DEFAULT", "d7/d4b/settings__gui_8cpp.html#a8931e5e0adf204a4fc99ce3241cbed6ba4f13c6cff03d67655455b3a851674dc0", null ],
      [ "RM_CHANGED_AGAINST_NEW", "d7/d4b/settings__gui_8cpp.html#a8931e5e0adf204a4fc99ce3241cbed6ba91113411f2040ccd2be26693d5a2f011", null ],
      [ "RM_END", "d7/d4b/settings__gui_8cpp.html#a8931e5e0adf204a4fc99ce3241cbed6bac88a0e985553617b75e8e3ac626a911a", null ]
    ] ],
    [ "SettingEntryFlags", "d7/d4b/settings__gui_8cpp.html#a7cea93fb55ed4e66386d11511a1cf2c7", [
      [ "SEF_LEFT_DEPRESSED", "d7/d4b/settings__gui_8cpp.html#a7cea93fb55ed4e66386d11511a1cf2c7a26203bcd0b94df3f87282d8303aba233", null ],
      [ "SEF_RIGHT_DEPRESSED", "d7/d4b/settings__gui_8cpp.html#a7cea93fb55ed4e66386d11511a1cf2c7a4d3449d382a6b0f308c6b89d21eca6e2", null ],
      [ "SEF_BUTTONS_MASK", "d7/d4b/settings__gui_8cpp.html#a7cea93fb55ed4e66386d11511a1cf2c7a09650e1d5e5c246a8637d9a7f74ab965", null ],
      [ "SEF_LAST_FIELD", "d7/d4b/settings__gui_8cpp.html#a7cea93fb55ed4e66386d11511a1cf2c7a3ee0d81884f1d9a8547a9e4a1fd56056", null ],
      [ "SEF_FILTERED", "d7/d4b/settings__gui_8cpp.html#a7cea93fb55ed4e66386d11511a1cf2c7a08b2c987991eb72e04e0e91b863fc964", null ]
    ] ],
    [ "WarnHiddenResult", "d7/d4b/settings__gui_8cpp.html#a2bbffaf9a311c332f2ab5ed047d5ec7a", [
      [ "WHR_NONE", "d7/d4b/settings__gui_8cpp.html#a2bbffaf9a311c332f2ab5ed047d5ec7aacd4f45a3c2d7674cfa0b8a46fafc24b1", null ],
      [ "WHR_CATEGORY", "d7/d4b/settings__gui_8cpp.html#a2bbffaf9a311c332f2ab5ed047d5ec7aab4c93e23115cf6a4476ec54773017477", null ],
      [ "WHR_TYPE", "d7/d4b/settings__gui_8cpp.html#a2bbffaf9a311c332f2ab5ed047d5ec7aae92fef92582c86923381ec86599bce82", null ],
      [ "WHR_CATEGORY_TYPE", "d7/d4b/settings__gui_8cpp.html#a2bbffaf9a311c332f2ab5ed047d5ec7aa0c12831bf021711b95b21e9f5acfc1f4", null ]
    ] ],
    [ "BuildMusicSetDropDownList", "d7/d4b/settings__gui_8cpp.html#aa942efed0f8b94d8459e73d65b7fd489", null ],
    [ "BuildSetDropDownList", "d7/d4b/settings__gui_8cpp.html#aee265bdbc1ee01dead0dec74daed4118", null ],
    [ "DrawArrowButtons", "d7/d4b/settings__gui_8cpp.html#a5d2ef420677f50bfe351d073a57ca7ff", null ],
    [ "DrawBoolButton", "d7/d4b/settings__gui_8cpp.html#abcabc98fb9356f812b54d374c78fb460", null ],
    [ "DrawDropDownButton", "d7/d4b/settings__gui_8cpp.html#a9638c8f5a5d74ccb7cbe669e7aaf1629", null ],
    [ "GetCurRes", "d7/d4b/settings__gui_8cpp.html#a38046d35c13ddf0011050f6bdd567f15", null ],
    [ "GetSettingsTree", "d7/d4b/settings__gui_8cpp.html#a9a94fdf20959d3e921977e7bc156dae1", null ],
    [ "InitGRFTownGeneratorNames", "d7/d4b/settings__gui_8cpp.html#aece86b3ea3e76cfc8927ff15cbec6065", null ],
    [ "ResolveVariableAddress", "d7/d4b/settings__gui_8cpp.html#a90ae8fb6d43619feb551ed14263750b3", null ],
    [ "ShowBaseSetTextfileWindow", "d7/d4b/settings__gui_8cpp.html#aad1a23f107dec8e03727d609fcdfe93a", null ],
    [ "ShowCustCurrency", "d7/d4b/settings__gui_8cpp.html#aca9f5c3d690c67d95f4f287dcf4ca155", null ],
    [ "ShowGameOptions", "d7/d4b/settings__gui_8cpp.html#af487449e7f642d3ab0a977a042027bda", null ],
    [ "ShowGameSettings", "d7/d4b/settings__gui_8cpp.html#ab8c4fab0620f49f44008aacd2cd6b81b", null ],
    [ "TownName", "d7/d4b/settings__gui_8cpp.html#ac898761b16af3ae7c3d874b8c39a4c5e", null ],
    [ "_autosave_dropdown", "d7/d4b/settings__gui_8cpp.html#ae6c8bccc9918afa3520760088a135cff", null ],
    [ "_circle_size", "d7/d4b/settings__gui_8cpp.html#af713f7a0af602dafcf93ec92a20936bc", null ],
    [ "_cust_currency_desc", "d7/d4b/settings__gui_8cpp.html#afce78f7b9f7bb347b8526088a173cee3", null ],
    [ "_driveside_dropdown", "d7/d4b/settings__gui_8cpp.html#a3d4845a92b61fd2769b07caf227e8d01", null ],
    [ "_font_zoom_dropdown", "d7/d4b/settings__gui_8cpp.html#ac7de4289f3c7d2d662180fd63031ac51", null ],
    [ "_game_options_desc", "d7/d4b/settings__gui_8cpp.html#a91d0cedcb5e29ca3a43ef97e8c4f83e1", null ],
    [ "_game_settings_restrict_dropdown", "d7/d4b/settings__gui_8cpp.html#ae4952de0118e16ae467a5874a6c39139", null ],
    [ "_grf_names", "d7/d4b/settings__gui_8cpp.html#a8317f958d147368990c0d203cac2f552", null ],
    [ "_gui_zoom_dropdown", "d7/d4b/settings__gui_8cpp.html#a008b3f6522d40f808efaaac5eee46702", null ],
    [ "_nb_grf_names", "d7/d4b/settings__gui_8cpp.html#a7fc3de8da90e3d21442a525d17180c47", null ],
    [ "_nb_orig_names", "d7/d4b/settings__gui_8cpp.html#ab27cd2489945547b7ceca1380cf284c6", null ],
    [ "_nested_cust_currency_widgets", "d7/d4b/settings__gui_8cpp.html#a61ac2226b107c78cff5ba8298cfd2cbb", null ],
    [ "_nested_game_options_widgets", "d7/d4b/settings__gui_8cpp.html#a1e5e26b10a8663b7e0143cee014a0bbe", null ],
    [ "_nested_settings_selection_widgets", "d7/d4b/settings__gui_8cpp.html#a0a52e6243aeee2b7e8749040cba63eda", null ],
    [ "_settings_selection_desc", "d7/d4b/settings__gui_8cpp.html#a8daa5484153bee0c2613a012cefbcc2d", null ],
    [ "LEVEL_WIDTH", "d7/d4b/settings__gui_8cpp.html#a8e9a8ce2c965afd5bc1d8014c9501060", null ],
    [ "SETTING_HEIGHT", "d7/d4b/settings__gui_8cpp.html#aaed4994b463560191c5c7daa9ebb6387", null ]
];
